[U-Boot] [PATCH 2/6] usb: omap5: Change the board_usb_init api to board_xhci_usb_init

Dan Murphy dmurphy at ti.com
Wed Oct 9 19:19:27 CEST 2013


Recent patches declares board_usb_init function prototype for a new
usb architecture.

Turning on the OMAP_XHCI defines cause a redefinition compiler failure.
So rename the API from board_usb_init to board_xhci_usb_init.

Signed-off-by: Dan Murphy <dmurphy at ti.com>
---
 board/ti/omap5_uevm/evm.c    |    4 ++--
 drivers/usb/host/xhci-omap.c |    6 +++---
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/usb/host/xhci-omap.c b/drivers/usb/host/xhci-omap.c
index a8702da..0093e63 100644
--- a/drivers/usb/host/xhci-omap.c
+++ b/drivers/usb/host/xhci-omap.c
@@ -182,11 +182,11 @@ static void omap_enable_phy_clocks(struct omap_xhci *omap)
 
 };
 
-inline int __board_usb_init(void)
+inline int __board_xhci_host_init(void)
 {
 	return 0;
 }
-int board_usb_init(void) __attribute__((weak, alias("__board_usb_init")));
+int board_xhci_host_init(void) __attribute__((weak, alias("__board_xhci_host_init")));
 
 static void dwc3_set_mode(struct dwc3 *dwc3_reg, u32 mode)
 {
@@ -295,7 +295,7 @@ int xhci_hcd_init(int index, struct xhci_hccr **hccr, struct xhci_hcor **hcor)
 	ctx->usb3_phy = (struct omap_usb3_phy *)OMAP_OCP1_SCP_BASE;
 	ctx->otg_wrapper = (struct omap_dwc_wrapper *)OMAP_OTG_WRAPPER_BASE;
 
-	ret = board_usb_init();
+	ret = board_xhci_host_init();
 	if (ret != 0) {
 		puts("Failed to initialize board for USB\n");
 		return ret;
diff --git a/board/ti/omap5_uevm/evm.c b/board/ti/omap5_uevm/evm.c
index 228df29..e85afdc 100644
--- a/board/ti/omap5_uevm/evm.c
+++ b/board/ti/omap5_uevm/evm.c
@@ -214,12 +214,12 @@ void usb_hub_reset_devices(int port)
 
 #ifdef CONFIG_USB_XHCI_OMAP
 /**
  * @brief board_usb_init - Configure EVM board specific configurations
  * for the LDO's and clocks for the USB blocks.
  *
  * @return 0
  */
-int board_usb_init(void)
+int board_xhci_host_init(void)
 {
 	int ret;
 #ifdef CONFIG_PALMAS_USB_SS_PWR
@@ -214,12 +214,12 @@ void usb_hub_reset_devices(int port)
 #ifdef CONFIG_USB_XHCI_OMAP
 /**
- * @brief board_usb_init - Configure EVM board specific configurations
+ * @brief board_xhci_host_init - Configure EVM board specific configurations
  * for the LDO's and clocks for the USB blocks.
  *
-- 
1.7.9.5



More information about the U-Boot mailing list